==> ZenTaoPMS.max2.0.rc1.php7.0.zip: zentaopms/module/auditplan/lang/zh-cn.php <==
<?php
$lang->auditplan->create        = '新建计划';
$lang->auditplan->edit          = '编辑';
$lang->auditplan->browse        = '浏览列表';

$lang->auditplan->browseAction = '计划列表';
$lang->auditplan->editAction   = '编辑计划';

$lang->auditplan->id            = '编号';
$lang->auditplan->item          = '检查项';
$lang->auditplan->name          = '名称';
$lang->auditplan->day           = '天';
$lang->auditplan->week          = '周';
$lang->auditplan->month         = '月';
$lang->auditplan->date          = '检查时间';
$lang->auditplan->cycle         = '周期设置';
$lang->auditplan->interval      = '间隔';
$lang->auditplan->deadline      = '过期时间';
$lang->auditplan->comment       = '备注';
$lang->auditplan->content       = '检查内容';
$lang->auditplan->check         = '检查';
$lang->auditplan->batchCheck    = '批量检查';
$lang->auditplan->checkedBy     = '检查人';
$lang->auditplan->result        = '检查结果';
$lang->auditplan->noData        = '暂无数据';
$lang->auditplan->noCheckList   = '暂无对应检查单，请到组织创建';
$lang->auditplan->common        = '检查计划';
$lang->auditplan->saveDraft     = '保存草稿';
$lang->auditplan->batchCreate   = '批量新建';
$lang->auditplan->nc            = '不符合项';
$lang->auditplan->process       = '所属过程';
$lang->auditplan->processType   = '过程分类';
$lang->auditplan->objectType    = '对象类型';
$lang->auditplan->objectID      = '检查对象';
$lang->auditplan->activity      = '活动';
$lang->auditplan->zoutput       = '文档';
$lang->auditplan->status        = '状态';
$lang->auditplan->severity      = '严重程度';
$lang->auditplan->createdBy     = '由谁创建';
$lang->auditplan->createdDate   = '创建时间';
$lang->auditplan->createNc      = '创建不符合项';
$lang->auditplan->desc          = '描述';
$lang->auditplan->assignedTo    = '指派给';
$lang->auditplan->checkDate     = '计划检查时间';
$lang->auditplan->realCheckDate = '实际检查时间';

$lang->auditplan->commentEmpty  = '当结果为否时，备注不能为空！';
$lang->auditplan->confirmDelete = '您确认删除该审核计划吗？';

$lang->auditplan->statusList = array();
$lang->auditplan->statusList['all']      = '所有';
$lang->auditplan->statusList['wait']     = '待检查';
$lang->auditplan->statusList['checked']  = '已检查';
$lang->auditplan->statusList['checking'] = '检查中';
$lang->auditplan->statusList['assignTo'] = '指派给我';
$lang->auditplan->statusList['delay']    = '已延期';
$lang->auditplan->statusList['today']    = '今日检查';

$lang->auditplan->moreStatusList = array();
$lang->auditplan->moreStatusList['yesterday'] = '昨日检查';
$lang->auditplan->moreStatusList['lastMonth'] = '上月检查';
$lang->auditplan->moreStatusList['month']     = '本月检查';
$lang->auditplan->moreStatusList['nextMonth'] = '下月检查';

$lang->auditplan->resultList = array();
$lang->auditplan->resultList['pass']    = '是';
$lang->auditplan->resultList['fail']    = '否';
$lang->auditplan->resultList['useless'] = '不适用';

==> ZenTaoPMS.max2.2.php7.0.zip: zentaopms/module/auditplan/lang/zh-cn.php <==
<?php
$lang->auditplan->create        = '新建计划';
$lang->auditplan->edit          = '编辑';
$lang->auditplan->browse        = '浏览列表';

$lang->auditplan->browseAction = '计划列表';
$lang->auditplan->editAction   = '编辑计划';

$lang->auditplan->id            = '编号';
$lang->auditplan->item          = '检查项';
$lang->auditplan->name          = '名称';
$lang->auditplan->day           = '天';
$lang->auditplan->week          = '周';
$lang->auditplan->month         = '月';
$lang->auditplan->date          = '检查时间';
$lang->auditplan->cycle         = '周期设置';
$lang->auditplan->interval      = '间隔';
$lang->auditplan->deadline      = '过期时间';
$lang->auditplan->comment       = '备注';
$lang->auditplan->content       = '检查内容';
$lang->auditplan->check         = '检查';
$lang->auditplan->batchCheck    = '批量检查';
$lang->auditplan->checkedBy     = '检查人';
$lang->auditplan->result        = '检查结果';
$lang->auditplan->noData        = '暂无数据';
$lang->auditplan->noCheckList   = '暂无对应检查单，请到后台创建';
$lang->auditplan->common        = '检查计划';
$lang->auditplan->saveDraft     = '保存草稿';
$lang->auditplan->batchCreate   = '批量新建';
$lang->auditplan->nc            = '不符合项';
$lang->auditplan->process       = '所属过程';
$lang->auditplan->processType   = '过程分类';
$lang->auditplan->objectType    = '对象类型';
$lang->auditplan->objectID      = '检查对象';
$lang->auditplan->activity      = '活动';
$lang->auditplan->zoutput       = '文档';
$lang->auditplan->status        = '状态';
$lang->auditplan->severity      = '严重程度';
$lang->auditplan->createdBy     = '由谁创建';
$lang->auditplan->createdDate   = '创建时间';
$lang->auditplan->createNc      = '创建不符合项';
$lang->auditplan->desc          = '描述';
$lang->auditplan->assignedTo    = '指派给';
$lang->auditplan->checkDate     = '计划检查时间';
$lang->auditplan->realCheckDate = '实际检查时间';

$lang->auditplan->commentEmpty  = '当结果为否时，备注不能为空！';
$lang->auditplan->confirmDelete = '您确认删除该审核计划吗？';

$lang->auditplan->statusList = array();
$lang->auditplan->statusList['all']      = '所有';
$lang->auditplan->statusList['wait']     = '待检查';
$lang->auditplan->statusList['checked']  = '已检查';
$lang->auditplan->statusList['checking'] = '检查中';
$lang->auditplan->statusList['assignTo'] = '指派给我';
$lang->auditplan->statusList['delay']    = '已延期';
$lang->auditplan->statusList['today']    = '今日检查';

$lang->auditplan->moreStatusList = array();
$lang->auditplan->moreStatusList['yesterday'] = '昨日检查';
$lang->auditplan->moreStatusList['lastMonth'] = '上月检查';
$lang->auditplan->moreStatusList['month']     = '本月检查';
$lang->auditplan->moreStatusList['nextMonth'] = '下月检查';

$lang->auditplan->resultList = array();
$lang->auditplan->resultList['pass']    = '是';
$lang->auditplan->resultList['fail']    = '否';
$lang->auditplan->resultList['useless'] = '不适用';
